@@ -3,7 +3,7 @@ from setux.main import banner
 
 doc = f'''{banner}
 
-setux [Module | Command] [Target]
+setux [Module | Command] [*args | **kwargs] [Target]
 
 Deploy Module or Execute Command on Target
 
