@@ -40,7 +40,7 @@ def safe(cmd, target):
 
 
 def prompt(target):
-    user = 'sudo' if target.sudo else target.login.name
+    user = target.login.name
     return f'{user}@{target.name} > '
 
 
